==> octave-epstk_1.9.orig.tar.gz: octave-epstk-1.9/m/erespar.m <==
ePath=oPath;
eGhostview=oGhostview;
eGhostscript=oGhostscript;
eFileName=oFileName;
eFile=oFile;
eUserUnit=oUserUnit;
eFac=oFac;
eFonts=oFonts;
eColorMaps=oColorMaps;
ePageWidth=oPageWidth;
ePageHeight=oPageHeight;
ePageOrientation=oPageOrientation;
eXScaleFac=oXScaleFac;
eYScaleFac=oYScaleFac;
eWinOrigin=oWinOrigin;
eWinWidth=oWinWidth;
eWinHeight=oWinHeight;
eWinFrameVisible=oWinFrameVisible;
eWinFrameLineWidth=oWinFrameLineWidth;
eWinTimeStampVisible=oWinTimeStampVisible;
eWinTimeStampFont=oWinTimeStampFont;
eWinTimeStampFontSize=oWinTimeStampFontSize;
ePlotAreaPos=oPlotAreaPos;
ePlotAreaWidth=oPlotAreaWidth;
ePlotAreaHeight=oPlotAreaHeight;
ePlotAreaXValueStart=oPlotAreaXValueStart;
ePlotAreaXValueEnd=oPlotAreaXValueEnd;
ePlotAreaYValueStart=oPlotAreaYValueStart;
ePlotAreaYValueEnd=oPlotAreaYValueEnd;
ePolarPlotAreaCenterPos=oPolarPlotAreaCenterPos;
ePolarPlotAreaRadMin=oPolarPlotAreaRadMin;
ePolarPlotAreaRadMax=oPolarPlotAreaRadMax;
ePolarPlotAreaAngStart=oPolarPlotAreaAngStart;
ePolarPlotAreaAngEnd=oPolarPlotAreaAngEnd;
ePolarPlotAreaValStart=oPolarPlotAreaValStart;
ePolarPlotAreaValEnd=oPolarPlotAreaValEnd;
ePlotTitleDistance=oPlotTitleDistance;
ePlotTitleFontSize=oPlotTitleFontSize;
ePlotTitleText=oPlotTitleText;
ePlotTitleTextFont=oPlotTitleTextFont;
eAxesColor=oAxesColor;
eAxesLineWidth=oAxesLineWidth;
eAxesTicShortLength=oAxesTicShortLength;
eAxesTicLongLength=oAxesTicLongLength;
eAxesTicLongMaxN=oAxesTicLongMaxN;
eAxesValueSpace=oAxesValueSpace;
eAxesValueFontSize=oAxesValueFontSize;
eAxesLabelFontSize=oAxesLabelFontSize;
eAxesLabelTextFont=oAxesLabelTextFont;
eAxesCrossOrigin=oAxesCrossOrigin;
eXGridLineWidth=oXGridLineWidth;
eXGridColor=oXGridColor;
eXGridDash=oXGridDash;
eXGridVisible=oXGridVisible;
eYGridLineWidth=oYGridLineWidth;
eYGridColor=oYGridColor;
eYGridDash=oYGridDash;
eYGridVisible=oYGridVisible;
ePolarRadiusGridLineWidth=oPolarRadiusGridLineWidth;
ePolarRadiusGridColor=oPolarRadiusGridColor;
ePolarRadiusGridDash=oPolarRadiusGridDash;
ePolarRadiusGridVisible=oPolarRadiusGridVisible;
ePolarAngleGridLineWidth=oPolarAngleGridLineWidth;
ePolarAngleGridColor=oPolarAngleGridColor;
ePolarAngleGridDash=oPolarAngleGridDash;
ePolarAngleGridVisible=oPolarAngleGridVisible;
eXAxisSouthScale=oXAxisSouthScale;
eXAxisSouthScaleType=oXAxisSouthScaleType;
eXAxisSouthValueFormat=oXAxisSouthValueFormat;
eXAxisSouthValueVisible=oXAxisSouthValueVisible;
eXAxisSouthLabelDistance=oXAxisSouthLabelDistance;
eXAxisSouthLabelText=oXAxisSouthLabelText;
eXAxisSouthVisible=oXAxisSouthVisible;
eXAxisNorthScale=oXAxisNorthScale;
eXAxisNorthScaleType=oXAxisNorthScaleType;
eXAxisNorthValueFormat=oXAxisNorthValueFormat;
eXAxisNorthValueVisible=oXAxisNorthValueVisible;
eXAxisNorthLabelDistance=oXAxisNorthLabelDistance;
eXAxisNorthLabelText=oXAxisNorthLabelText;
eXAxisNorthVisible=oXAxisNorthVisible;
eYAxisWestScale=oYAxisWestScale;
eYAxisWestScaleType=oYAxisWestScaleType;
eYAxisWestValueFormat=oYAxisWestValueFormat;
eYAxisWestValueVisible=oYAxisWestValueVisible;
eYAxisWestLabelDistance=oYAxisWestLabelDistance;
eYAxisWestLabelText=oYAxisWestLabelText;
eYAxisWestVisible=oYAxisWestVisible;
eYAxisEastScale=oYAxisEastScale;
eYAxisEastScaleType=oYAxisEastScaleType;
eYAxisEastValueFormat=oYAxisEastValueFormat;
eYAxisEastValueVisible=oYAxisEastValueVisible;
eYAxisEastLabelDistance=oYAxisEastLabelDistance;
eYAxisEastLabelText=oYAxisEastLabelText;
eYAxisEastVisible=oYAxisEastVisible;
ePolarAxisRadScale=oPolarAxisRadScale;
ePolarAxisRadValueFormat=oPolarAxisRadValueFormat;
ePolarAxisRadValueVisible=oPolarAxisRadValueVisible;
ePolarAxisRadVisible=oPolarAxisRadVisible;
ePolarAxisAngScale=oPolarAxisAngScale;
ePolarAxisAngValueFormat=oPolarAxisAngValueFormat;
ePolarAxisAngValueVisible=oPolarAxisAngValueVisible;
ePolarAxisAngVisible=oPolarAxisAngVisible;
ePlotLineNr=oPlotLineNr;
ePolarPlotLineNr=oPolarPlotLineNr;
ePlotLineColor=oPlotLineColor;
ePlotLineDash=oPlotLineDash;
ePlotLineWidth=oPlotLineWidth;
ePlotLineInterpolation=oPlotLineInterpolation;
ePlotLegendPos=oPlotLegendPos;
ePlotLegendFontSize=oPlotLegendFontSize;
ePlotLegendDistance=oPlotLegendDistance;
ePlotLegendTextFont=oPlotLegendTextFont;
eImageDefaultColorMap=oImageDefaultColorMap;
eImageFrameVisible=oImageFrameVisible;
eImageLegendPos=oImageLegendPos;
eImageLegendWidth=oImageLegendWidth;
eImageLegendHeight=oImageLegendHeight;
eImageLegendScale=oImageLegendScale;
eImageLegendValueFormat=oImageLegendValueFormat;
eImageLegendValueVisible=oImageLegendValueVisible;
eImageLegendLabelDistance=oImageLegendLabelDistance;
eImageLegendLabelText=oImageLegendLabelText;
eImageLegendVisible=oImageLegendVisible;
eParamPos=oParamPos;
eParamFontSize=oParamFontSize;
eParamLineDistance=oParamLineDistance;
eParamTextValueDistance=oParamTextValueDistance;
eParamText=oParamText;
eParamTextFont=oParamTextFont;
eParamValue=oParamValue;
eParamValueFont=oParamValueFont;
eLineWidth=oLineWidth;
eLineColor=oLineColor;
eLineDash=oLineDash;
eTextFont=oTextFont;
eTextFontSize=oTextFontSize;
eTextPos=oTextPos;
eTextColor=oTextColor;
eTextAlignment=oTextAlignment;
eTextRotation=oTextRotation;
eContourLineWidth=oContourLineWidth;
eContourLineColor=oContourLineColor;
eContourLineDash=oContourLineDash;
eContourScale=oContourScale;
eContourValueVisible=oContourValueVisible;
eContourValueFormat=oContourValueFormat;
eContourValueFont=oContourValueFont;
eContourValueFontSize=oContourValueFontSize;
eContourValueDistance=oContourValueDistance;
eContourLevelsMaxN=oContourLevelsMaxN;
eTabBackgroundColor=oTabBackgroundColor;
eTabFrameVisible=oTabFrameVisible;
eTabFrameLineWidth=oTabFrameLineWidth;
eTabFrameColor=oTabFrameColor;
eTabFrameDash=oTabFrameDash;
eTabXLineVisible=oTabXLineVisible;
eTabXLineWidth=oTabXLineWidth;
eTabXLineColor=oTabXLineColor;
eTabXLineDash=oTabXLineDash;
eTabYLineVisible=oTabYLineVisible;
eTabYLineWidth=oTabYLineWidth;
eTabYLineColor=oTabYLineColor;
eTabYLineDash =oTabYLineDash ;

==> octave-epstk_2.0.orig.tar.gz: octave-epstk-2.0/m/erespar.m <==
ePath=oPath;
eGhostview=oGhostview;
eGhostscript=oGhostscript;
eFileName=oFileName;
eFile=oFile;
eUserUnit=oUserUnit;
eFac=oFac;
eFonts=oFonts;
eColorMaps=oColorMaps;
ePageWidth=oPageWidth;
ePageHeight=oPageHeight;
ePageOrientation=oPageOrientation;
ePageReflection=oPageReflection;
eXScaleFac=oXScaleFac;
eYScaleFac=oYScaleFac;
eWinWidth=oWinWidth;
eWinHeight=oWinHeight;
eWinFrameVisible=oWinFrameVisible;
eWinFrameLineWidth=oWinFrameLineWidth;
eWinTimeStampVisible=oWinTimeStampVisible;
eWinTimeStampFont=oWinTimeStampFont;
eWinTimeStampFontSize=oWinTimeStampFontSize;
ePlotAreaPos=oPlotAreaPos;
ePlotAreaWidth=oPlotAreaWidth;
ePlotAreaHeight=oPlotAreaHeight;
ePlotAreaXValueStart=oPlotAreaXValueStart;
ePlotAreaXValueEnd=oPlotAreaXValueEnd;
ePlotAreaYValueStart=oPlotAreaYValueStart;
ePlotAreaYValueEnd=oPlotAreaYValueEnd;
ePolarPlotAreaCenterPos=oPolarPlotAreaCenterPos;
ePolarPlotAreaRadMin=oPolarPlotAreaRadMin;
ePolarPlotAreaRadMax=oPolarPlotAreaRadMax;
ePolarPlotAreaAngStart=oPolarPlotAreaAngStart;
ePolarPlotAreaAngEnd=oPolarPlotAreaAngEnd;
ePolarPlotAreaValStart=oPolarPlotAreaValStart;
ePolarPlotAreaValEnd=oPolarPlotAreaValEnd;
ePlotTitleDistance=oPlotTitleDistance;
ePlotTitleFontSize=oPlotTitleFontSize;
ePlotTitleText=oPlotTitleText;
ePlotTitleTextFont=oPlotTitleTextFont;
eAxesColor=oAxesColor;
eAxesLineWidth=oAxesLineWidth;
eAxesTicShortLength=oAxesTicShortLength;
eAxesTicLongLength=oAxesTicLongLength;
eAxesTicLongMaxN=oAxesTicLongMaxN;
eAxesValueSpace=oAxesValueSpace;
eAxesValueFontSize=oAxesValueFontSize;
eAxesLabelFontSize=oAxesLabelFontSize;
eAxesLabelTextFont=oAxesLabelTextFont;
eAxesCrossOrigin=oAxesCrossOrigin;
eXGridLineWidth=oXGridLineWidth;
eXGridColor=oXGridColor;
eXGridDash=oXGridDash;
eXGridVisible=oXGridVisible;
eYGridLineWidth=oYGridLineWidth;
eYGridColor=oYGridColor;
eYGridDash=oYGridDash;
eYGridVisible=oYGridVisible;
ePolarRadiusGridLineWidth=oPolarRadiusGridLineWidth;
ePolarRadiusGridColor=oPolarRadiusGridColor;
ePolarRadiusGridDash=oPolarRadiusGridDash;
ePolarRadiusGridVisible=oPolarRadiusGridVisible;
ePolarAngleGridLineWidth=oPolarAngleGridLineWidth;
ePolarAngleGridColor=oPolarAngleGridColor;
ePolarAngleGridDash=oPolarAngleGridDash;
ePolarAngleGridVisible=oPolarAngleGridVisible;
eXAxisSouthScale=oXAxisSouthScale;
eXAxisSouthScaleType=oXAxisSouthScaleType;
eXAxisSouthValueFormat=oXAxisSouthValueFormat;
eXAxisSouthValueVisible=oXAxisSouthValueVisible;
eXAxisSouthValuePos=oXAxisSouthValuePos;
eXAxisSouthLabelDistance=oXAxisSouthLabelDistance;
eXAxisSouthLabelText=oXAxisSouthLabelText;
eXAxisSouthVisible=oXAxisSouthVisible;
eXAxisNorthScale=oXAxisNorthScale;
eXAxisNorthScaleType=oXAxisNorthScaleType;
eXAxisNorthValueFormat=oXAxisNorthValueFormat;
eXAxisNorthValueVisible=oXAxisNorthValueVisible;
eXAxisNorthValuePos=oXAxisNorthValuePos;
eXAxisNorthLabelDistance=oXAxisNorthLabelDistance;
eXAxisNorthLabelText=oXAxisNorthLabelText;
eXAxisNorthVisible=oXAxisNorthVisible;
eYAxisWestScale=oYAxisWestScale;
eYAxisWestScaleType=oYAxisWestScaleType;
eYAxisWestValueFormat=oYAxisWestValueFormat;
eYAxisWestValueVisible=oYAxisWestValueVisible;
eYAxisWestValuePos=oYAxisWestValuePos;
eYAxisWestLabelDistance=oYAxisWestLabelDistance;
eYAxisWestLabelText=oYAxisWestLabelText;
eYAxisWestVisible=oYAxisWestVisible;
eYAxisEastScale=oYAxisEastScale;
eYAxisEastScaleType=oYAxisEastScaleType;
eYAxisEastValueFormat=oYAxisEastValueFormat;
eYAxisEastValueVisible=oYAxisEastValueVisible;
eYAxisEastValuePos=oYAxisEastValuePos;
eYAxisEastLabelDistance=oYAxisEastLabelDistance;
eYAxisEastLabelText=oYAxisEastLabelText;
eYAxisEastVisible=oYAxisEastVisible;
ePieSliceNo=oPieSliceNo;
ePolarAxisRadScale=oPolarAxisRadScale;
ePolarAxisRadScaleType=oPolarAxisRadScaleType;
ePolarAxisRadValueFormat=oPolarAxisRadValueFormat;
ePolarAxisRadValueVisible=oPolarAxisRadValueVisible;
ePolarAxisRadValuePos=oPolarAxisRadValuePos;
ePolarAxisRadVisible=oPolarAxisRadVisible;
ePolarAxisAngScale=oPolarAxisAngScale;
ePolarAxisAngValueFormat=oPolarAxisAngValueFormat;
ePolarAxisAngValueVisible=oPolarAxisAngValueVisible;
ePolarAxisAngValueAngle=oPolarAxisAngValueAngle;
ePolarAxisAngVisible=oPolarAxisAngVisible;
ePlotLineNo=oPlotLineNo;
ePolarPlotLineNo=oPolarPlotLineNo;
ePlotLineColor=oPlotLineColor;
ePlotLineDash=oPlotLineDash;
ePlotLineWidth=oPlotLineWidth;
ePlotLineInterpolation=oPlotLineInterpolation;
ePlotLegendPos=oPlotLegendPos;
ePlotLegendFontSize=oPlotLegendFontSize;
ePlotLegendDistance=oPlotLegendDistance;
ePlotLegendTextFont=oPlotLegendTextFont;
eImageDefaultColorMap=oImageDefaultColorMap;
eImageFrameVisible=oImageFrameVisible;
eImageLegendPos=oImageLegendPos;
eImageLegendWidth=oImageLegendWidth;
eImageLegendHeight=oImageLegendHeight;
eImageLegendScale=oImageLegendScale;
eImageLegendScaleType=oImageLegendScaleType;
eImageLegendValueFormat=oImageLegendValueFormat;
eImageLegendValueVisible=oImageLegendValueVisible;
eImageLegendValuePos=oImageLegendValuePos;
eImageLegendLabelDistance=oImageLegendLabelDistance;
eImageLegendLabelText=oImageLegendLabelText;
eImageLegendVisible=oImageLegendVisible;
eParamPos=oParamPos;
eParamFontSize=oParamFontSize;
eParamLineDistance=oParamLineDistance;
eParamTextValueDistance=oParamTextValueDistance;
eParamText=oParamText;
eParamTextFont=oParamTextFont;
eParamValue=oParamValue;
eParamValueFont=oParamValueFont;
eLineWidth=oLineWidth;
eLineColor=oLineColor;
eLineDash=oLineDash;
eTextFont=oTextFont;
eTextFontSize=oTextFontSize;
eTextPos=oTextPos;
eTextColor=oTextColor;
eTextAlignment=oTextAlignment;
eTextRotation=oTextRotation;
eTextLimitWord=oTextLimitWord;
eTextLimitPara=oTextLimitPara;
eTextBoxFeedLine=oTextBoxFeedLine;
eTextBoxFeedPara=oTextBoxFeedPara;
eTextBoxSpaceNorth=oTextBoxSpaceNorth;
eTextBoxSpaceSouth=oTextBoxSpaceSouth;
eTextBoxSpaceWest=oTextBoxSpaceWest;
eTextBoxSpaceEast=oTextBoxSpaceEast;
eContourLineWidth=oContourLineWidth;
eContourLineColor=oContourLineColor;
eContourLineDash=oContourLineDash;
eContourScale=oContourScale;
eContourValueVisible=oContourValueVisible;
eContourValueFormat=oContourValueFormat;
eContourValueFont=oContourValueFont;
eContourValueFontSize=oContourValueFontSize;
eContourValueDistance=oContourValueDistance;
eContourLevelsMaxN=oContourLevelsMaxN;
eTabBackgroundColor=oTabBackgroundColor;
eTabFrameVisible=oTabFrameVisible;
eTabFrameLineWidth=oTabFrameLineWidth;
eTabFrameColor=oTabFrameColor;
eTabFrameDash=oTabFrameDash;
eTabXLineVisible=oTabXLineVisible;
eTabXLineWidth=oTabXLineWidth;
eTabXLineColor=oTabXLineColor;
eTabXLineDash=oTabXLineDash;
eTabYLineVisible=oTabYLineVisible;
eTabYLineWidth=oTabYLineWidth;
eTabYLineColor=oTabYLineColor;
eTabYLineDash =oTabYLineDash ;
